@@ -51,21 +51,21 @@ from cpacspy.utils import MSG_STAB_NEUTRAL, MSG_STAB_NOT_ENOUGH, MSG_STAB_ONE_PA
 def get_filter(df, alt_list, mach_list, aos_list, aoa_list):
     """Get a dataframe filter for a set of parameters lists."""
 
-    filt = pd.Series(True, index=df.index)
+    filter = pd.Series(True, index=df.index)
 
     if alt_list:
-        filt &= df["altitude"].isin(alt_list)
+        filter &= df["altitude"].isin(alt_list)
 
     if mach_list:
-        filt &= df["machNumber"].isin(mach_list)
+        filter &= df["machNumber"].isin(mach_list)
 
     if aos_list:
-        filt &= df["angleOfSideslip"].isin(aos_list)
+        filter &= df["angleOfSideslip"].isin(aos_list)
 
     if aoa_list:
-        filt &= df["angleOfAttack"].isin(aoa_list)
+        filter &= df["angleOfAttack"].isin(aoa_list)
 
-    return filt
+    return filter
 
 
 class AeroMap:
@@ -580,11 +580,12 @@ class AeroMap:
         alt_list = listify(alt)
         mach_list = listify(mach)
         aos_list = listify(aos)
+        aoa_list = []
 
         if len(alt_list) > 1 or len(mach_list) > 1 or len(aos_list) > 1:
             msg = MSG_STAB_ONE_PARAM
 
-        filt = get_filter(self.df, alt_list, mach_list, aos_list, [])
+        filt = get_filter(self.df, alt_list, mach_list, aos_list, aoa_list)
         df_filt = self.df.loc[filt]
         x = df_filt["angleOfAttack"].to_numpy()
         y = df_filt["cms"].to_numpy()
@@ -604,7 +605,7 @@ class AeroMap:
     def check_directional_stability(self, alt=None, mach=None, aoa=None):
         """Check directional stability (cml vs aos) with other parameters as filter (optional).
         The stability is checked by making a linear regression on cml vs aos and analyzing the
-        slope sign.
+        slope sign. With the CPACS angle convention cml vs aos slope must be positive to be stable.
 
         Args:
             alt (list, optional): List of altitudes to filter. Defaults to None.
@@ -622,12 +623,14 @@ class AeroMap:
         alt_list = listify(alt)
         mach_list = listify(mach)
         aoa_list = listify(aoa)
+        aos_list = []
 
         if len(alt_list) > 1 or len(mach_list) > 1 or len(aoa_list) > 1:
             msg = MSG_STAB_ONE_PARAM
 
-        filt = get_filter(self.df, alt_list, mach_list, aoa_list, [])
+        filt = get_filter(self.df, alt_list, mach_list, aos_list, aoa_list)
         df_filt = self.df.loc[filt]
+
         x = df_filt["angleOfSideslip"].to_numpy()
         y = df_filt["cml"].to_numpy()
 
@@ -638,7 +641,7 @@ class AeroMap:
 
         if res.slope == 0:
             return False, MSG_STAB_NEUTRAL
-        elif res.slope < 0:
+        elif res.slope > 0:
             return True, msg
         else:
             return False, msg
@@ -664,11 +667,12 @@ class AeroMap:
         alt_list = listify(alt)
         mach_list = listify(mach)
         aoa_list = listify(aoa)
+        aos_list = []
 
         if len(alt_list) > 1 or len(mach_list) > 1 or len(aoa_list) > 1:
             msg = MSG_STAB_ONE_PARAM
 
-        filt = get_filter(self.df, alt_list, mach_list, aoa_list, [])
+        filt = get_filter(self.df, alt_list, mach_list, aos_list, aoa_list)
         df_filt = self.df.loc[filt]
         x = df_filt["angleOfSideslip"].to_numpy()
         y = df_filt["cmd"].to_numpy()
