@@ -30,8 +30,8 @@ CPACSPY_LIB = Path(__file__).absolute().parent
 CPACSPY_ROOT = CPACSPY_LIB.parents[1]
 EXAMPLES_PATH = Path(CPACSPY_ROOT, "examples")
 TESTS_PATH = Path(CPACSPY_ROOT, "tests")
-D150_TESTS_PATH = str(Path(TESTS_PATH, "D150_simple.xml"))
-PROPELLER_TESTS_PATH = str(Path(TESTS_PATH, "SimpleAircraft_propeller.xml"))
+D150_TESTS_PATH = Path(TESTS_PATH, "D150_simple.xml")
+PROPELLER_TESTS_PATH = Path(TESTS_PATH, "SimpleAircraft_propeller.xml")
 
 # XPATH
 AC_NAME_XPATH = "/cpacs/header/name"
